All Classes and Interfaces
Class
Description
You do not have sufficient access to perform this action.
Input parameters for adding replication regions to a specific key.
AddKeyReplicationRegionsRequest Marshaller
Output from adding replication regions to a key.
Contains information about an alias.
An AWS Arn.
AssociateMpaTeamRequest Marshaller
The metadata used to create the certificate signing request.
This request can cause an inconsistent state for the resource.
CreateAliasRequest MarshallerCreateKeyRequest MarshallerDeleteAliasRequest MarshallerDeleteKeyRequest MarshallerDeleteResourcePolicyRequest Marshaller
The shared information used when deriving a key using ECDH.
Input parameters for disabling default key replication regions for the account.
DisableDefaultKeyReplicationRegionsRequest Marshaller
Output from disabling default key replication regions for the account.
DisassociateMpaTeamRequest Marshaller
Input parameters for enabling default key replication regions for the account.
EnableDefaultKeyReplicationRegionsRequest Marshaller
Output from enabling default key replication regions for the account.
Link between an endpoint property and the
AwsEndpointAttribute it represents.
Parameter information for key material export using AS2805 key cryptogram format.
The attributes for IPEK generation during export.
Key derivation parameter information for key material export using asymmetric ECDH key exchange method.
Parameter information for IPEK generation during export.
Parameter information for key material export using asymmetric RSA wrap and unwrap key exchange method.
Parameter information for key material export from Amazon Web Services Payment Cryptography using TR-31 or TR-34 or
RSA wrap and unwrap key exchange method.
ExportKeyRequest Marshaller
Parameter information for key material export using symmetric TR-31 key exchange method.
Parameter information for key material export using the asymmetric TR-34 key exchange method.
GetAliasRequest MarshallerGetCertificateSigningRequestRequest Marshaller
Input parameters for retrieving the account's default key replication regions.
GetDefaultKeyReplicationRegionsRequest Marshaller
Output containing the account's current default key replication configuration.
GetKeyRequest MarshallerGetMpaTeamAssociationRequest MarshallerGetParametersForExportRequest MarshallerGetParametersForImportRequest MarshallerGetPublicKeyCertificateRequest MarshallerGetResourcePolicyRequest MarshallerIdentifiers for variables declared within the rule engine, e.g.
Parameter information for key material import using AS2805 key cryptogram format.
Key derivation parameter information for key material import using asymmetric ECDH key exchange method.
Parameter information for key material import using asymmetric RSA wrap and unwrap key exchange method.
Parameter information for key material import into Amazon Web Services Payment Cryptography using TR-31 or TR-34 or
RSA wrap and unwrap key exchange method.
ImportKeyRequest Marshaller
Parameter information for key material import using symmetric TR-31 key exchange method.
Parameter information for key material import using the asymmetric TR-34 key exchange method.
The request processing has failed because of an unknown error, exception, or failure.
Metadata about an Amazon Web Services Payment Cryptography key.
The role of the key, the algorithm it supports, and the cryptographic operations allowed with the key.
Optional metadata for export associated with the key material.
The list of cryptographic operations that you can perform using the key.
Defines the source of a key
Defines the replication state of a key
Defines the state of a key
Metadata about an Amazon Web Services Payment Cryptography key.
Represents the output for the
PaymentCryptographyClient.listAliasesPaginator(software.amazon.awssdk.services.paymentcryptography.model.ListAliasesRequest)
operation which is a paginated operation.
Represents the output for the
PaymentCryptographyAsyncClient.listAliasesPaginator(software.amazon.awssdk.services.paymentcryptography.model.ListAliasesRequest)
operation which is a paginated operation.ListAliasesRequest Marshaller
Represents the output for the
PaymentCryptographyClient.listKeysPaginator(software.amazon.awssdk.services.paymentcryptography.model.ListKeysRequest)
operation which is a paginated operation.
Represents the output for the
PaymentCryptographyAsyncClient.listKeysPaginator(software.amazon.awssdk.services.paymentcryptography.model.ListKeysRequest)
operation which is a paginated operation.ListKeysRequest Marshaller
Represents the output for the
PaymentCryptographyClient.listTagsForResourcePaginator(software.amazon.awssdk.services.paymentcryptography.model.ListTagsForResourceRequest)
operation which is a paginated operation.
Represents the output for the
PaymentCryptographyAsyncClient.listTagsForResourcePaginator(software.amazon.awssdk.services.paymentcryptography.model.ListTagsForResourceRequest)
operation which is a paginated operation.ListTagsForResourceRequest Marshaller
The status of an MPA session.
The details of an MPA team association with a protected operation.
Defines the replication type of a key
Service client for accessing Payment Cryptography Control Plane asynchronously.
A builder for creating an instance of
PaymentCryptographyAsyncClient.The parameters object used to resolve the auth schemes for the PaymentCryptography service.
A builder for a
PaymentCryptographyAuthSchemeParams.An auth scheme provider for PaymentCryptography service.
This includes configuration specific to Payment Cryptography Control Plane that is supported by both
PaymentCryptographyClientBuilder and PaymentCryptographyAsyncClientBuilder.Service client for accessing Payment Cryptography Control Plane.
A builder for creating an instance of
PaymentCryptographyClient.The parameters object used to resolve an endpoint for the PaymentCryptography service.
An endpoint provider for PaymentCryptography.
Class to expose the service client settings to the user.
A builder for creating a
PaymentCryptographyServiceClientConfiguration
The resource-based policy would grant public access to the key.
PutResourcePolicyRequest Marshaller
Input parameters for removing replication regions from a specific key.
RemoveKeyReplicationRegionsRequest Marshaller
Output from removing replication regions from a key.
Represents the replication status information for a key in a replication region for Multi-Region key replication.
The request was denied due to resource not found.
RestoreKeyRequest Marshaller
Parameter information for root public key certificate import.
Represents a URL to be used internally for endpoint resolution.
This request would cause a service quota to be exceeded.
The service cannot complete the request.
Defines the Algorithm used to generate the certificate signing request
StartKeyUsageRequest MarshallerStopKeyUsageRequest Marshaller
A structure that contains information about a tag.
TagResourceRequest Marshaller
The request was denied due to request throttling.
Parameter information for trusted public key certificate import.
UntagResourceRequest MarshallerUpdateAliasRequest Marshaller
The request was denied due to an invalid request error.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.
Parameter information for generating a WrappedKeyBlock for key exchange.